@@ -3,13 +3,14 @@
 
 # Copyright (c) Jupyter Development Team.
 # Distributed under the terms of the Modified BSD License.
-from notebook.notebookapp import NotebookApp
+
 from traitlets import Unicode
 
+from .server import ServerApp
 from .handlers import add_handlers, LabConfig
 
 
-class LabLauncherApp(NotebookApp):
+class LabLauncherApp(ServerApp):
 
     default_url = Unicode('/lab',
                           help='The default URL to redirect to from `/`')
@@ -18,7 +19,7 @@ class LabLauncherApp(NotebookApp):
 
     def start(self):
         add_handlers(self.web_app, self.lab_config)
-        NotebookApp.start(self)
+        ServerApp.start(self)
 
 
 main = LabLauncherApp.launch_instance
